# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import StrictBool
from mett_dataportal_sdk.models.ppi_all_neighbors_response_schema import (
    PPIAllNeighborsResponseSchema,
)
from mett_dataportal_sdk.models.ppi_network_properties_response_schema import (
    PPINetworkPropertiesResponseSchema,
)
from mett_dataportal_sdk.models.ppi_network_response_schema import (
    PPINetworkResponseSchema,
)
from mett_dataportal_sdk.models.ppi_score_types_response_schema import (
    PPIScoreTypesResponseSchema,
)
from mett_dataportal_sdk.models.ppi_search_response_schema import (
    PPISearchResponseSchema,
)

from mett_dataportal_sdk.api_client import ApiClient, RequestSerialized
from mett_dataportal_sdk.api_response import ApiResponse
from mett_dataportal_sdk.rest import RESTResponseType


class ProteinProteinInteractionsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def dataportal_api_interactions_ppi_endpoints_get_all_protein_neighbors(
        self,
        protein_id: Annotated[
            Optional[StrictStr], Field(description="UniProt ID of the protein")
        ] = None,
        locus_tag: Annotated[
            Optional[StrictStr], Field(description="Locus tag of the protein")
        ] = None,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Species acronym filter")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PPIAllNeighborsResponseSchema:
        """Get all protein neighbors (raw data)

        Get all neighbors for a specific protein without algorithm processing. Returns raw interaction data for custom analysis in Jupyter notebooks. Can search by protein_id (UniProt ID) or locus_tag.

        :param protein_id: UniProt ID of the protein
        :type protein_id: str
        :param locus_tag: Locus tag of the protein
        :type locus_tag: str
        :param species_acronym: Species acronym filter
        :type species_acronym: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ppi_endpoints_get_all_protein_neighbors_serialize(
            protein_id=protein_id,
            locus_tag=locus_tag,
            species_acronym=species_acronym,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PPIAllNeighborsResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_interactions_ppi_endpoints_get_all_protein_neighbors_with_http_info(
        self,
        protein_id: Annotated[
            Optional[StrictStr], Field(description="UniProt ID of the protein")
        ] = None,
        locus_tag: Annotated[
            Optional[StrictStr], Field(description="Locus tag of the protein")
        ] = None,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Species acronym filter")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PPIAllNeighborsResponseSchema]:
        """Get all protein neighbors (raw data)

        Get all neighbors for a specific protein without algorithm processing. Returns raw interaction data for custom analysis in Jupyter notebooks. Can search by protein_id (UniProt ID) or locus_tag.

        :param protein_id: UniProt ID of the protein
        :type protein_id: str
        :param locus_tag: Locus tag of the protein
        :type locus_tag: str
        :param species_acronym: Species acronym filter
        :type species_acronym: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ppi_endpoints_get_all_protein_neighbors_serialize(
            protein_id=protein_id,
            locus_tag=locus_tag,
            species_acronym=species_acronym,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PPIAllNeighborsResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_interactions_ppi_endpoints_get_all_protein_neighbors_without_preload_content(
        self,
        protein_id: Annotated[
            Optional[StrictStr], Field(description="UniProt ID of the protein")
        ] = None,
        locus_tag: Annotated[
            Optional[StrictStr], Field(description="Locus tag of the protein")
        ] = None,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Species acronym filter")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all protein neighbors (raw data)

        Get all neighbors for a specific protein without algorithm processing. Returns raw interaction data for custom analysis in Jupyter notebooks. Can search by protein_id (UniProt ID) or locus_tag.

        :param protein_id: UniProt ID of the protein
        :type protein_id: str
        :param locus_tag: Locus tag of the protein
        :type locus_tag: str
        :param species_acronym: Species acronym filter
        :type species_acronym: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ppi_endpoints_get_all_protein_neighbors_serialize(
            protein_id=protein_id,
            locus_tag=locus_tag,
            species_acronym=species_acronym,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PPIAllNeighborsResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_interactions_ppi_endpoints_get_all_protein_neighbors_serialize(
        self,
        protein_id,
        locus_tag,
        species_acronym,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if protein_id is not None:
            _query_params.append(("protein_id", protein_id))

        if locus_tag is not None:
            _query_params.append(("locus_tag", locus_tag))

        if species_acronym is not None:
            _query_params.append(("species_acronym", species_acronym))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["RoleBasedJWTAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/ppi/neighbors",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def dataportal_api_interactions_ppi_endpoints_get_available_score_types(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PPIScoreTypesResponseSchema:
        """Get available score types

        Get list of available score types for PPI filtering

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ppi_endpoints_get_available_score_types_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PPIScoreTypesResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_interactions_ppi_endpoints_get_available_score_types_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PPIScoreTypesResponseSchema]:
        """Get available score types

        Get list of available score types for PPI filtering

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ppi_endpoints_get_available_score_types_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PPIScoreTypesResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_interactions_ppi_endpoints_get_available_score_types_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get available score types

        Get list of available score types for PPI filtering

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ppi_endpoints_get_available_score_types_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PPIScoreTypesResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_interactions_ppi_endpoints_get_available_score_types_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["RoleBasedJWTAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/ppi/scores/available",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def dataportal_api_interactions_ppi_endpoints_get_ppi_network(
        self,
        score_type: StrictStr,
        score_threshold: Annotated[
            Optional[
                Union[
                    Annotated[float, Field(le=1, strict=True, ge=0)],
                    Annotated[int, Field(le=1, strict=True, ge=0)],
                ]
            ],
            Field(description="Score threshold for network construction"),
        ] = None,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Species acronym filter")
        ] = None,
        include_properties: Annotated[
            Optional[StrictBool],
            Field(description="Whether to include network properties"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PPINetworkResponseSchema:
        """Get PPI network data

        Get network data for a specific score type and threshold

        :param score_type: (required)
        :type score_type: str
        :param score_threshold: Score threshold for network construction
        :type score_threshold: float
        :param species_acronym: Species acronym filter
        :type species_acronym: str
        :param include_properties: Whether to include network properties
        :type include_properties: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = (
            self._dataportal_api_interactions_ppi_endpoints_get_ppi_network_serialize(
                score_type=score_type,
                score_threshold=score_threshold,
                species_acronym=species_acronym,
                include_properties=include_properties,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PPINetworkResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_interactions_ppi_endpoints_get_ppi_network_with_http_info(
        self,
        score_type: StrictStr,
        score_threshold: Annotated[
            Optional[
                Union[
                    Annotated[float, Field(le=1, strict=True, ge=0)],
                    Annotated[int, Field(le=1, strict=True, ge=0)],
                ]
            ],
            Field(description="Score threshold for network construction"),
        ] = None,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Species acronym filter")
        ] = None,
        include_properties: Annotated[
            Optional[StrictBool],
            Field(description="Whether to include network properties"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PPINetworkResponseSchema]:
        """Get PPI network data

        Get network data for a specific score type and threshold

        :param score_type: (required)
        :type score_type: str
        :param score_threshold: Score threshold for network construction
        :type score_threshold: float
        :param species_acronym: Species acronym filter
        :type species_acronym: str
        :param include_properties: Whether to include network properties
        :type include_properties: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = (
            self._dataportal_api_interactions_ppi_endpoints_get_ppi_network_serialize(
                score_type=score_type,
                score_threshold=score_threshold,
                species_acronym=species_acronym,
                include_properties=include_properties,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PPINetworkResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_interactions_ppi_endpoints_get_ppi_network_without_preload_content(
        self,
        score_type: StrictStr,
        score_threshold: Annotated[
            Optional[
                Union[
                    Annotated[float, Field(le=1, strict=True, ge=0)],
                    Annotated[int, Field(le=1, strict=True, ge=0)],
                ]
            ],
            Field(description="Score threshold for network construction"),
        ] = None,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Species acronym filter")
        ] = None,
        include_properties: Annotated[
            Optional[StrictBool],
            Field(description="Whether to include network properties"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get PPI network data

        Get network data for a specific score type and threshold

        :param score_type: (required)
        :type score_type: str
        :param score_threshold: Score threshold for network construction
        :type score_threshold: float
        :param species_acronym: Species acronym filter
        :type species_acronym: str
        :param include_properties: Whether to include network properties
        :type include_properties: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = (
            self._dataportal_api_interactions_ppi_endpoints_get_ppi_network_serialize(
                score_type=score_type,
                score_threshold=score_threshold,
                species_acronym=species_acronym,
                include_properties=include_properties,
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PPINetworkResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_interactions_ppi_endpoints_get_ppi_network_serialize(
        self,
        score_type,
        score_threshold,
        species_acronym,
        include_properties,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if score_type is not None:
            _path_params["score_type"] = score_type
        # process the query parameters
        if score_threshold is not None:
            _query_params.append(("score_threshold", score_threshold))

        if species_acronym is not None:
            _query_params.append(("species_acronym", species_acronym))

        if include_properties is not None:
            _query_params.append(("include_properties", include_properties))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["RoleBasedJWTAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/ppi/network/{score_type}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def dataportal_api_interactions_ppi_endpoints_get_ppi_network_properties(
        self,
        score_type: Annotated[
            StrictStr, Field(description="Score type for network construction")
        ],
        score_threshold: Annotated[
            Optional[
                Union[
                    Annotated[float, Field(le=1, strict=True, ge=0)],
                    Annotated[int, Field(le=1, strict=True, ge=0)],
                ]
            ],
            Field(description="Score threshold for network construction"),
        ] = None,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Species acronym filter")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PPINetworkPropertiesResponseSchema:
        """Get PPI network properties

        Get network properties (nodes, edges, density, clustering) for a specific score type and threshold

        :param score_type: Score type for network construction (required)
        :type score_type: str
        :param score_threshold: Score threshold for network construction
        :type score_threshold: float
        :param species_acronym: Species acronym filter
        :type species_acronym: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ppi_endpoints_get_ppi_network_properties_serialize(
            score_type=score_type,
            score_threshold=score_threshold,
            species_acronym=species_acronym,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PPINetworkPropertiesResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_interactions_ppi_endpoints_get_ppi_network_properties_with_http_info(
        self,
        score_type: Annotated[
            StrictStr, Field(description="Score type for network construction")
        ],
        score_threshold: Annotated[
            Optional[
                Union[
                    Annotated[float, Field(le=1, strict=True, ge=0)],
                    Annotated[int, Field(le=1, strict=True, ge=0)],
                ]
            ],
            Field(description="Score threshold for network construction"),
        ] = None,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Species acronym filter")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PPINetworkPropertiesResponseSchema]:
        """Get PPI network properties

        Get network properties (nodes, edges, density, clustering) for a specific score type and threshold

        :param score_type: Score type for network construction (required)
        :type score_type: str
        :param score_threshold: Score threshold for network construction
        :type score_threshold: float
        :param species_acronym: Species acronym filter
        :type species_acronym: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ppi_endpoints_get_ppi_network_properties_serialize(
            score_type=score_type,
            score_threshold=score_threshold,
            species_acronym=species_acronym,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PPINetworkPropertiesResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_interactions_ppi_endpoints_get_ppi_network_properties_without_preload_content(
        self,
        score_type: Annotated[
            StrictStr, Field(description="Score type for network construction")
        ],
        score_threshold: Annotated[
            Optional[
                Union[
                    Annotated[float, Field(le=1, strict=True, ge=0)],
                    Annotated[int, Field(le=1, strict=True, ge=0)],
                ]
            ],
            Field(description="Score threshold for network construction"),
        ] = None,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Species acronym filter")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get PPI network properties

        Get network properties (nodes, edges, density, clustering) for a specific score type and threshold

        :param score_type: Score type for network construction (required)
        :type score_type: str
        :param score_threshold: Score threshold for network construction
        :type score_threshold: float
        :param species_acronym: Species acronym filter
        :type species_acronym: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ppi_endpoints_get_ppi_network_properties_serialize(
            score_type=score_type,
            score_threshold=score_threshold,
            species_acronym=species_acronym,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PPINetworkPropertiesResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_interactions_ppi_endpoints_get_ppi_network_properties_serialize(
        self,
        score_type,
        score_threshold,
        species_acronym,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if score_type is not None:
            _query_params.append(("score_type", score_type))

        if score_threshold is not None:
            _query_params.append(("score_threshold", score_threshold))

        if species_acronym is not None:
            _query_params.append(("species_acronym", species_acronym))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["RoleBasedJWTAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/ppi/network-properties",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def dataportal_api_interactions_ppi_endpoints_search_ppi_interactions(
        self,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Species acronym (e.g., 'PV', 'BU')")
        ] = None,
        isolate_name: Annotated[
            Optional[StrictStr],
            Field(description="Isolate name (e.g., 'BU_ATCC8492', 'PV_ATCC8482')"),
        ] = None,
        score_type: Annotated[
            Optional[StrictStr], Field(description="Score type to filter by")
        ] = None,
        score_threshold: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Minimum score threshold"),
        ] = None,
        has_xlms: Annotated[
            Optional[StrictBool], Field(description="Filter by XL-MS evidence")
        ] = None,
        has_string: Annotated[
            Optional[StrictBool], Field(description="Filter by STRING evidence")
        ] = None,
        has_operon: Annotated[
            Optional[StrictBool], Field(description="Filter by operon evidence")
        ] = None,
        has_ecocyc: Annotated[
            Optional[StrictBool], Field(description="Filter by EcoCyc evidence")
        ] = None,
        protein_id: Annotated[
            Optional[StrictStr],
            Field(description="Filter interactions involving specific protein"),
        ] = None,
        locus_tag: Annotated[
            Optional[StrictStr],
            Field(description="Filter interactions involving specific locus tag"),
        ] = None,
        page: Annotated[
            Optional[Annotated[int, Field(strict=True, ge=1)]],
            Field(description="Page number"),
        ] = None,
        per_page: Annotated[
            Optional[Annotated[int, Field(le=100000, strict=True, ge=1)]],
            Field(description="Results per page"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PPISearchResponseSchema:
        """Search protein-protein interactions

        Search for protein-protein interactions with various filtering options. Can search by protein_id (UniProt ID) or locus_tag.

        :param species_acronym: Species acronym (e.g., 'PV', 'BU')
        :type species_acronym: str
        :param isolate_name: Isolate name (e.g., 'BU_ATCC8492', 'PV_ATCC8482')
        :type isolate_name: str
        :param score_type: Score type to filter by
        :type score_type: str
        :param score_threshold: Minimum score threshold
        :type score_threshold: float
        :param has_xlms: Filter by XL-MS evidence
        :type has_xlms: bool
        :param has_string: Filter by STRING evidence
        :type has_string: bool
        :param has_operon: Filter by operon evidence
        :type has_operon: bool
        :param has_ecocyc: Filter by EcoCyc evidence
        :type has_ecocyc: bool
        :param protein_id: Filter interactions involving specific protein
        :type protein_id: str
        :param locus_tag: Filter interactions involving specific locus tag
        :type locus_tag: str
        :param page: Page number
        :type page: int
        :param per_page: Results per page
        :type per_page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ppi_endpoints_search_ppi_interactions_serialize(
            species_acronym=species_acronym,
            isolate_name=isolate_name,
            score_type=score_type,
            score_threshold=score_threshold,
            has_xlms=has_xlms,
            has_string=has_string,
            has_operon=has_operon,
            has_ecocyc=has_ecocyc,
            protein_id=protein_id,
            locus_tag=locus_tag,
            page=page,
            per_page=per_page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PPISearchResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_interactions_ppi_endpoints_search_ppi_interactions_with_http_info(
        self,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Species acronym (e.g., 'PV', 'BU')")
        ] = None,
        isolate_name: Annotated[
            Optional[StrictStr],
            Field(description="Isolate name (e.g., 'BU_ATCC8492', 'PV_ATCC8482')"),
        ] = None,
        score_type: Annotated[
            Optional[StrictStr], Field(description="Score type to filter by")
        ] = None,
        score_threshold: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Minimum score threshold"),
        ] = None,
        has_xlms: Annotated[
            Optional[StrictBool], Field(description="Filter by XL-MS evidence")
        ] = None,
        has_string: Annotated[
            Optional[StrictBool], Field(description="Filter by STRING evidence")
        ] = None,
        has_operon: Annotated[
            Optional[StrictBool], Field(description="Filter by operon evidence")
        ] = None,
        has_ecocyc: Annotated[
            Optional[StrictBool], Field(description="Filter by EcoCyc evidence")
        ] = None,
        protein_id: Annotated[
            Optional[StrictStr],
            Field(description="Filter interactions involving specific protein"),
        ] = None,
        locus_tag: Annotated[
            Optional[StrictStr],
            Field(description="Filter interactions involving specific locus tag"),
        ] = None,
        page: Annotated[
            Optional[Annotated[int, Field(strict=True, ge=1)]],
            Field(description="Page number"),
        ] = None,
        per_page: Annotated[
            Optional[Annotated[int, Field(le=100000, strict=True, ge=1)]],
            Field(description="Results per page"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PPISearchResponseSchema]:
        """Search protein-protein interactions

        Search for protein-protein interactions with various filtering options. Can search by protein_id (UniProt ID) or locus_tag.

        :param species_acronym: Species acronym (e.g., 'PV', 'BU')
        :type species_acronym: str
        :param isolate_name: Isolate name (e.g., 'BU_ATCC8492', 'PV_ATCC8482')
        :type isolate_name: str
        :param score_type: Score type to filter by
        :type score_type: str
        :param score_threshold: Minimum score threshold
        :type score_threshold: float
        :param has_xlms: Filter by XL-MS evidence
        :type has_xlms: bool
        :param has_string: Filter by STRING evidence
        :type has_string: bool
        :param has_operon: Filter by operon evidence
        :type has_operon: bool
        :param has_ecocyc: Filter by EcoCyc evidence
        :type has_ecocyc: bool
        :param protein_id: Filter interactions involving specific protein
        :type protein_id: str
        :param locus_tag: Filter interactions involving specific locus tag
        :type locus_tag: str
        :param page: Page number
        :type page: int
        :param per_page: Results per page
        :type per_page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ppi_endpoints_search_ppi_interactions_serialize(
            species_acronym=species_acronym,
            isolate_name=isolate_name,
            score_type=score_type,
            score_threshold=score_threshold,
            has_xlms=has_xlms,
            has_string=has_string,
            has_operon=has_operon,
            has_ecocyc=has_ecocyc,
            protein_id=protein_id,
            locus_tag=locus_tag,
            page=page,
            per_page=per_page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PPISearchResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_interactions_ppi_endpoints_search_ppi_interactions_without_preload_content(
        self,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Species acronym (e.g., 'PV', 'BU')")
        ] = None,
        isolate_name: Annotated[
            Optional[StrictStr],
            Field(description="Isolate name (e.g., 'BU_ATCC8492', 'PV_ATCC8482')"),
        ] = None,
        score_type: Annotated[
            Optional[StrictStr], Field(description="Score type to filter by")
        ] = None,
        score_threshold: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Minimum score threshold"),
        ] = None,
        has_xlms: Annotated[
            Optional[StrictBool], Field(description="Filter by XL-MS evidence")
        ] = None,
        has_string: Annotated[
            Optional[StrictBool], Field(description="Filter by STRING evidence")
        ] = None,
        has_operon: Annotated[
            Optional[StrictBool], Field(description="Filter by operon evidence")
        ] = None,
        has_ecocyc: Annotated[
            Optional[StrictBool], Field(description="Filter by EcoCyc evidence")
        ] = None,
        protein_id: Annotated[
            Optional[StrictStr],
            Field(description="Filter interactions involving specific protein"),
        ] = None,
        locus_tag: Annotated[
            Optional[StrictStr],
            Field(description="Filter interactions involving specific locus tag"),
        ] = None,
        page: Annotated[
            Optional[Annotated[int, Field(strict=True, ge=1)]],
            Field(description="Page number"),
        ] = None,
        per_page: Annotated[
            Optional[Annotated[int, Field(le=100000, strict=True, ge=1)]],
            Field(description="Results per page"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Search protein-protein interactions

        Search for protein-protein interactions with various filtering options. Can search by protein_id (UniProt ID) or locus_tag.

        :param species_acronym: Species acronym (e.g., 'PV', 'BU')
        :type species_acronym: str
        :param isolate_name: Isolate name (e.g., 'BU_ATCC8492', 'PV_ATCC8482')
        :type isolate_name: str
        :param score_type: Score type to filter by
        :type score_type: str
        :param score_threshold: Minimum score threshold
        :type score_threshold: float
        :param has_xlms: Filter by XL-MS evidence
        :type has_xlms: bool
        :param has_string: Filter by STRING evidence
        :type has_string: bool
        :param has_operon: Filter by operon evidence
        :type has_operon: bool
        :param has_ecocyc: Filter by EcoCyc evidence
        :type has_ecocyc: bool
        :param protein_id: Filter interactions involving specific protein
        :type protein_id: str
        :param locus_tag: Filter interactions involving specific locus tag
        :type locus_tag: str
        :param page: Page number
        :type page: int
        :param per_page: Results per page
        :type per_page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ppi_endpoints_search_ppi_interactions_serialize(
            species_acronym=species_acronym,
            isolate_name=isolate_name,
            score_type=score_type,
            score_threshold=score_threshold,
            has_xlms=has_xlms,
            has_string=has_string,
            has_operon=has_operon,
            has_ecocyc=has_ecocyc,
            protein_id=protein_id,
            locus_tag=locus_tag,
            page=page,
            per_page=per_page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PPISearchResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_interactions_ppi_endpoints_search_ppi_interactions_serialize(
        self,
        species_acronym,
        isolate_name,
        score_type,
        score_threshold,
        has_xlms,
        has_string,
        has_operon,
        has_ecocyc,
        protein_id,
        locus_tag,
        page,
        per_page,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if species_acronym is not None:
            _query_params.append(("species_acronym", species_acronym))

        if isolate_name is not None:
            _query_params.append(("isolate_name", isolate_name))

        if score_type is not None:
            _query_params.append(("score_type", score_type))

        if score_threshold is not None:
            _query_params.append(("score_threshold", score_threshold))

        if has_xlms is not None:
            _query_params.append(("has_xlms", has_xlms))

        if has_string is not None:
            _query_params.append(("has_string", has_string))

        if has_operon is not None:
            _query_params.append(("has_operon", has_operon))

        if has_ecocyc is not None:
            _query_params.append(("has_ecocyc", has_ecocyc))

        if protein_id is not None:
            _query_params.append(("protein_id", protein_id))

        if locus_tag is not None:
            _query_params.append(("locus_tag", locus_tag))

        if page is not None:
            _query_params.append(("page", page))

        if per_page is not None:
            _query_params.append(("per_page", per_page))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["RoleBasedJWTAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/ppi/interactions",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Set
from typing_extensions import Self


class AMRSchema(BaseModel):
    """
    AMRSchema
    """  # noqa: E501

    gene_symbol: Optional[StrictStr] = None
    sequence_name: Optional[StrictStr] = None
    scope: Optional[StrictStr] = None
    element_type: Optional[StrictStr] = None
    element_subtype: Optional[StrictStr] = None
    drug_class: Optional[StrictStr] = None
    drug_subclass: Optional[StrictStr] = None
    uf_keyword: Optional[List[StrictStr]] = None
    uf_ecnumber: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = [
        "gene_symbol",
        "sequence_name",
        "scope",
        "element_type",
        "element_subtype",
        "drug_class",
        "drug_subclass",
        "uf_keyword",
        "uf_ecnumber",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AMRSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if gene_symbol (nullable) is None
        # and model_fields_set contains the field
        if self.gene_symbol is None and "gene_symbol" in self.model_fields_set:
            _dict["gene_symbol"] = None

        # set to None if sequence_name (nullable) is None
        # and model_fields_set contains the field
        if self.sequence_name is None and "sequence_name" in self.model_fields_set:
            _dict["sequence_name"] = None

        # set to None if scope (nullable) is None
        # and model_fields_set contains the field
        if self.scope is None and "scope" in self.model_fields_set:
            _dict["scope"] = None

        # set to None if element_type (nullable) is None
        # and model_fields_set contains the field
        if self.element_type is None and "element_type" in self.model_fields_set:
            _dict["element_type"] = None

        # set to None if element_subtype (nullable) is None
        # and model_fields_set contains the field
        if self.element_subtype is None and "element_subtype" in self.model_fields_set:
            _dict["element_subtype"] = None

        # set to None if drug_class (nullable) is None
        # and model_fields_set contains the field
        if self.drug_class is None and "drug_class" in self.model_fields_set:
            _dict["drug_class"] = None

        # set to None if drug_subclass (nullable) is None
        # and model_fields_set contains the field
        if self.drug_subclass is None and "drug_subclass" in self.model_fields_set:
            _dict["drug_subclass"] = None

        # set to None if uf_keyword (nullable) is None
        # and model_fields_set contains the field
        if self.uf_keyword is None and "uf_keyword" in self.model_fields_set:
            _dict["uf_keyword"] = None

        # set to None if uf_ecnumber (nullable) is None
        # and model_fields_set contains the field
        if self.uf_ecnumber is None and "uf_ecnumber" in self.model_fields_set:
            _dict["uf_ecnumber"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AMRSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "gene_symbol": obj.get("gene_symbol"),
                "sequence_name": obj.get("sequence_name"),
                "scope": obj.get("scope"),
                "element_type": obj.get("element_type"),
                "element_subtype": obj.get("element_subtype"),
                "drug_class": obj.get("drug_class"),
                "drug_subclass": obj.get("drug_subclass"),
                "uf_keyword": obj.get("uf_keyword"),
                "uf_ecnumber": obj.get("uf_ecnumber"),
            }
        )
        return _obj



"""Species CLI commands."""

from __future__ import annotations

from typing import List, Optional

import typer  # type: ignore[import]

from ..output import print_full_table, print_json, print_tsv
from ..utils import comma_join, ensure_client, handle_raw_response, merge_params

species_app = typer.Typer(help="Species endpoints")


@species_app.command("list")
def list_species(
    ctx: typer.Context,
    format: Optional[str] = typer.Option(
        None, "--format", "-f", help="Output format: json|tsv (default: table)"
    ),
) -> None:
    client = ensure_client(ctx)
    api_format = format or "json"  # Default to JSON for API request
    species = client.list_species(format=api_format)

    if format == "tsv":
        print_tsv(species)
    elif format == "json":
        print_json(species)
    else:
        # No format specified - display as table
        print_full_table(species, title="Species")


@species_app.command("genomes")
def species_genomes_list(
    ctx: typer.Context,
    species_acronym: str = typer.Argument(..., help="Species acronym, e.g. BU"),
    query: Optional[str] = typer.Option(
        None, "--query", "-q", help="Optional search term"
    ),
    isolates: Optional[List[str]] = typer.Option(
        None, "--isolate", "-i", help="Filter by isolate(s)"
    ),
    page: Optional[int] = typer.Option(None, "--page", "-p"),
    per_page: Optional[int] = typer.Option(None, "--per-page"),
    sort_field: Optional[str] = typer.Option(None, "--sort-field"),
    sort_order: Optional[str] = typer.Option(None, "--sort-order"),
    format: Optional[str] = typer.Option(None, "--format", "-f", help="json|tsv"),
) -> None:
    client = ensure_client(ctx)
    params = merge_params(
        {
            "query": query,
            "page": page,
            "per_page": per_page,
            "sortField": sort_field,
            "sortOrder": sort_order,
            "isolates": comma_join(isolates),
        }
    )
    response = client.raw_request(
        "GET",
        f"/api/species/{species_acronym}/genomes",
        params=params,
        format=format,
    )
    handle_raw_response(response, format, title=f"Genomes ({species_acronym})")


@species_app.command("search-genomes")
def species_search_genomes(
    ctx: typer.Context,
    species_acronym: str = typer.Argument(..., help="Species acronym, e.g. BU"),
    query: Optional[str] = typer.Option(None, "--query", "-q"),
    isolates: Optional[List[str]] = typer.Option(None, "--isolate", "-i"),
    page: Optional[int] = typer.Option(None, "--page", "-p"),
    per_page: Optional[int] = typer.Option(None, "--per-page"),
    sort_field: Optional[str] = typer.Option(None, "--sort-field"),
    sort_order: Optional[str] = typer.Option(None, "--sort-order"),
    format: Optional[str] = typer.Option(None, "--format", "-f", help="json|tsv"),
) -> None:
    client = ensure_client(ctx)
    params = merge_params(
        {
            "query": query,
            "page": page,
            "per_page": per_page,
            "sortField": sort_field,
            "sortOrder": sort_order,
            "isolates": comma_join(isolates),
        }
    )
    response = client.raw_request(
        "GET",
        f"/api/species/{species_acronym}/genomes/search",
        params=params,
        format=format,
    )
    handle_raw_response(response, format, title=f"Genomes search ({species_acronym})")



"""Version information for the METT Data Portal client."""

from __future__ import annotations

try:
    from importlib.metadata import version, PackageNotFoundError
except ImportError:
    # Python < 3.8
    from importlib_metadata import version, PackageNotFoundError  # type: ignore[no-redef]

try:
    __version__ = version("mett")
except PackageNotFoundError:
    # Package is not installed, read from pyproject.toml
    from pathlib import Path

    try:
        # Try tomllib (Python 3.11+)
        try:
            import tomllib
        except ImportError:
            # Fall back to tomli for Python < 3.11
            import tomli as tomllib  # type: ignore[no-redef]

        pyproject_path = Path(__file__).parent.parent.parent / "pyproject.toml"
        with open(pyproject_path, "rb") as f:
            pyproject = tomllib.load(f)
        __version__ = pyproject["project"]["version"]
    except (FileNotFoundError, KeyError, ImportError):
        # Fallback if pyproject.toml is not found or can't be parsed
        __version__ = "0.0.1a1"

__all__ = ["__version__"]



# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    StrictFloat,
    StrictInt,
    StrictStr,
    field_validator,
)
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Set
from typing_extensions import Self


class SearchRequestSchema(BaseModel):
    """
    SearchRequestSchema
    """  # noqa: E501

    database: StrictStr = Field(
        description="Database identifier (consolidated or isolate-specific)"
    )
    threshold: StrictStr
    threshold_value: Union[StrictFloat, StrictInt]
    input: StrictStr
    mx: Optional[StrictStr] = None
    e: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="E")
    dom_e: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="domE")
    inc_e: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="incE")
    incdom_e: Optional[Union[StrictFloat, StrictInt]] = Field(
        default=None, alias="incdomE"
    )
    t: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="T")
    dom_t: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="domT")
    inc_t: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="incT")
    incdom_t: Optional[Union[StrictFloat, StrictInt]] = Field(
        default=None, alias="incdomT"
    )
    popen: Optional[
        Union[
            Annotated[float, Field(strict=True, ge=0)],
            Annotated[int, Field(strict=True, ge=0)],
        ]
    ] = Field(default=0.02, description="Gap open penalty")
    pextend: Optional[
        Union[
            Annotated[float, Field(strict=True, ge=0)],
            Annotated[int, Field(strict=True, ge=0)],
        ]
    ] = Field(default=0.4, description="Gap extend penalty")
    __properties: ClassVar[List[str]] = [
        "database",
        "threshold",
        "threshold_value",
        "input",
        "mx",
        "E",
        "domE",
        "incE",
        "incdomE",
        "T",
        "domT",
        "incT",
        "incdomT",
        "popen",
        "pextend",
    ]

    @field_validator("threshold")
    def threshold_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(["evalue", "bitscore"]):
            raise ValueError("must be one of enum values ('evalue', 'bitscore')")
        return value

    @field_validator("mx")
    def mx_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(
            ["BLOSUM62", "BLOSUM45", "BLOSUM90", "PAM30", "PAM70", "PAM250"]
        ):
            raise ValueError(
                "must be one of enum values ('BLOSUM62', 'BLOSUM45', 'BLOSUM90', 'PAM30', 'PAM70', 'PAM250')"
            )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SearchRequestSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if mx (nullable) is None
        # and model_fields_set contains the field
        if self.mx is None and "mx" in self.model_fields_set:
            _dict["mx"] = None

        # set to None if e (nullable) is None
        # and model_fields_set contains the field
        if self.e is None and "e" in self.model_fields_set:
            _dict["E"] = None

        # set to None if dom_e (nullable) is None
        # and model_fields_set contains the field
        if self.dom_e is None and "dom_e" in self.model_fields_set:
            _dict["domE"] = None

        # set to None if inc_e (nullable) is None
        # and model_fields_set contains the field
        if self.inc_e is None and "inc_e" in self.model_fields_set:
            _dict["incE"] = None

        # set to None if incdom_e (nullable) is None
        # and model_fields_set contains the field
        if self.incdom_e is None and "incdom_e" in self.model_fields_set:
            _dict["incdomE"] = None

        # set to None if t (nullable) is None
        # and model_fields_set contains the field
        if self.t is None and "t" in self.model_fields_set:
            _dict["T"] = None

        # set to None if dom_t (nullable) is None
        # and model_fields_set contains the field
        if self.dom_t is None and "dom_t" in self.model_fields_set:
            _dict["domT"] = None

        # set to None if inc_t (nullable) is None
        # and model_fields_set contains the field
        if self.inc_t is None and "inc_t" in self.model_fields_set:
            _dict["incT"] = None

        # set to None if incdom_t (nullable) is None
        # and model_fields_set contains the field
        if self.incdom_t is None and "incdom_t" in self.model_fields_set:
            _dict["incdomT"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SearchRequestSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "database": obj.get("database"),
                "threshold": obj.get("threshold"),
                "threshold_value": obj.get("threshold_value"),
                "input": obj.get("input"),
                "mx": obj.get("mx"),
                "E": obj.get("E"),
                "domE": obj.get("domE"),
                "incE": obj.get("incE"),
                "incdomE": obj.get("incdomE"),
                "T": obj.get("T"),
                "domT": obj.get("domT"),
                "incT": obj.get("incT"),
                "incdomT": obj.get("incdomT"),
                "popen": obj.get("popen") if obj.get("popen") is not None else 0.02,
                "pextend": obj.get("pextend")
                if obj.get("pextend") is not None
                else 0.4,
            }
        )
        return _obj



# coding: utf-8

# flake8: noqa
"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from mett_dataportal_sdk.models.amr_schema import AMRSchema
from mett_dataportal_sdk.models.contig_schema import ContigSchema
from mett_dataportal_sdk.models.dbx_ref_schema import DBXRefSchema
from mett_dataportal_sdk.models.drug_mic_data_schema import DrugMICDataSchema
from mett_dataportal_sdk.models.drug_mic_search_query_schema import (
    DrugMICSearchQuerySchema,
)
from mett_dataportal_sdk.models.drug_metabolism_data_schema import (
    DrugMetabolismDataSchema,
)
from mett_dataportal_sdk.models.drug_metabolism_search_query_schema import (
    DrugMetabolismSearchQuerySchema,
)
from mett_dataportal_sdk.models.essentiality_search_query_schema import (
    EssentialitySearchQuerySchema,
)
from mett_dataportal_sdk.models.fitness_search_query_schema import (
    FitnessSearchQuerySchema,
)
from mett_dataportal_sdk.models.gene_advanced_search_query_schema import (
    GeneAdvancedSearchQuerySchema,
)
from mett_dataportal_sdk.models.gene_paginated_response_schema import (
    GenePaginatedResponseSchema,
)
from mett_dataportal_sdk.models.gene_response_schema import GeneResponseSchema
from mett_dataportal_sdk.models.gene_search_query_schema import GeneSearchQuerySchema
from mett_dataportal_sdk.models.genes_by_genome_query_schema import (
    GenesByGenomeQuerySchema,
)
from mett_dataportal_sdk.models.genome_paginated_response_schema import (
    GenomePaginatedResponseSchema,
)
from mett_dataportal_sdk.models.genome_response_schema import GenomeResponseSchema
from mett_dataportal_sdk.models.genome_search_query_schema import (
    GenomeSearchQuerySchema,
)
from mett_dataportal_sdk.models.genomes_by_isolate_names_query_schema import (
    GenomesByIsolateNamesQuerySchema,
)
from mett_dataportal_sdk.models.get_all_genes_query_schema import GetAllGenesQuerySchema
from mett_dataportal_sdk.models.get_all_genomes_query_schema import (
    GetAllGenomesQuerySchema,
)
from mett_dataportal_sdk.models.mutant_growth_search_query_schema import (
    MutantGrowthSearchQuerySchema,
)
from mett_dataportal_sdk.models.ppi_all_neighbors_response_schema import (
    PPIAllNeighborsResponseSchema,
)
from mett_dataportal_sdk.models.ppi_all_neighbors_schema import PPIAllNeighborsSchema
from mett_dataportal_sdk.models.ppi_interaction_schema import PPIInteractionSchema
from mett_dataportal_sdk.models.ppi_neighbors_query_schema import (
    PPINeighborsQuerySchema,
)
from mett_dataportal_sdk.models.ppi_network_properties_query_schema import (
    PPINetworkPropertiesQuerySchema,
)
from mett_dataportal_sdk.models.ppi_network_properties_response_schema import (
    PPINetworkPropertiesResponseSchema,
)
from mett_dataportal_sdk.models.ppi_network_properties_schema import (
    PPINetworkPropertiesSchema,
)
from mett_dataportal_sdk.models.ppi_network_query_schema import PPINetworkQuerySchema
from mett_dataportal_sdk.models.ppi_network_response_schema import (
    PPINetworkResponseSchema,
)
from mett_dataportal_sdk.models.ppi_network_schema import PPINetworkSchema
from mett_dataportal_sdk.models.ppi_score_types_response_schema import (
    PPIScoreTypesResponseSchema,
)
from mett_dataportal_sdk.models.ppi_search_query_schema import PPISearchQuerySchema
from mett_dataportal_sdk.models.ppi_search_response_schema import (
    PPISearchResponseSchema,
)
from mett_dataportal_sdk.models.paginated_response_schema import PaginatedResponseSchema
from mett_dataportal_sdk.models.paginated_strain_drug_mic_response_schema import (
    PaginatedStrainDrugMICResponseSchema,
)
from mett_dataportal_sdk.models.paginated_strain_drug_metabolism_response_schema import (
    PaginatedStrainDrugMetabolismResponseSchema,
)
from mett_dataportal_sdk.models.pagination_metadata_schema import (
    PaginationMetadataSchema,
)
from mett_dataportal_sdk.models.proteomics_search_query_schema import (
    ProteomicsSearchQuerySchema,
)
from mett_dataportal_sdk.models.reactions_search_query_schema import (
    ReactionsSearchQuerySchema,
)
from mett_dataportal_sdk.models.response_status import ResponseStatus
from mett_dataportal_sdk.models.result_query_schema import ResultQuerySchema
from mett_dataportal_sdk.models.search_request_schema import SearchRequestSchema
from mett_dataportal_sdk.models.species_genome_search_query_schema import (
    SpeciesGenomeSearchQuerySchema,
)
from mett_dataportal_sdk.models.strain_drug_data_response_schema import (
    StrainDrugDataResponseSchema,
)
from mett_dataportal_sdk.models.success_response_schema import SuccessResponseSchema
from mett_dataportal_sdk.models.ttp_compound_interactions_query_schema import (
    TTPCompoundInteractionsQuerySchema,
)
from mett_dataportal_sdk.models.ttp_gene_interactions_query_schema import (
    TTPGeneInteractionsQuerySchema,
)
from mett_dataportal_sdk.models.ttp_interaction_query_schema import (
    TTPInteractionQuerySchema,
)



# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import StrictBool
from mett_dataportal_sdk.models.success_response_schema import SuccessResponseSchema

from mett_dataportal_sdk.api_client import ApiClient, RequestSerialized
from mett_dataportal_sdk.api_response import ApiResponse
from mett_dataportal_sdk.rest import RESTResponseType


class MutantGrowthApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def dataportal_api_experimental_mutant_growth_endpoints_search_mutant_growth(
        self,
        locus_tags: Annotated[
            Optional[StrictStr],
            Field(description="Comma-separated list of locus tags to search for"),
        ] = None,
        uniprot_ids: Annotated[
            Optional[StrictStr],
            Field(description="Comma-separated list of UniProt IDs to search for"),
        ] = None,
        media: Annotated[
            Optional[StrictStr], Field(description="Filter by growth media")
        ] = None,
        experimental_condition: Annotated[
            Optional[StrictStr], Field(description="Filter by experimental condition")
        ] = None,
        min_doubling_time: Annotated[
            Optional[
                Union[
                    Annotated[float, Field(strict=True, ge=0)],
                    Annotated[int, Field(strict=True, ge=0)],
                ]
            ],
            Field(description="Minimum doubling time in hours"),
        ] = None,
        max_doubling_time: Annotated[
            Optional[
                Union[
                    Annotated[float, Field(strict=True, ge=0)],
                    Annotated[int, Field(strict=True, ge=0)],
                ]
            ],
            Field(description="Maximum doubling time in hours"),
        ] = None,
        exclude_double_picked: Annotated[
            Optional[StrictBool],
            Field(description="Exclude double-picked mutants (isdoublepicked=True)"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SuccessResponseSchema:
        """Search mutant growth data with filters

        Search for mutant growth data across genes with optional filters. Supports identifier-based search and discovery mode (filter-only queries).

        :param locus_tags: Comma-separated list of locus tags to search for
        :type locus_tags: str
        :param uniprot_ids: Comma-separated list of UniProt IDs to search for
        :type uniprot_ids: str
        :param media: Filter by growth media
        :type media: str
        :param experimental_condition: Filter by experimental condition
        :type experimental_condition: str
        :param min_doubling_time: Minimum doubling time in hours
        :type min_doubling_time: float
        :param max_doubling_time: Maximum doubling time in hours
        :type max_doubling_time: float
        :param exclude_double_picked: Exclude double-picked mutants (isdoublepicked=True)
        :type exclude_double_picked: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_experimental_mutant_growth_endpoints_search_mutant_growth_serialize(
            locus_tags=locus_tags,
            uniprot_ids=uniprot_ids,
            media=media,
            experimental_condition=experimental_condition,
            min_doubling_time=min_doubling_time,
            max_doubling_time=max_doubling_time,
            exclude_double_picked=exclude_double_picked,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_experimental_mutant_growth_endpoints_search_mutant_growth_with_http_info(
        self,
        locus_tags: Annotated[
            Optional[StrictStr],
            Field(description="Comma-separated list of locus tags to search for"),
        ] = None,
        uniprot_ids: Annotated[
            Optional[StrictStr],
            Field(description="Comma-separated list of UniProt IDs to search for"),
        ] = None,
        media: Annotated[
            Optional[StrictStr], Field(description="Filter by growth media")
        ] = None,
        experimental_condition: Annotated[
            Optional[StrictStr], Field(description="Filter by experimental condition")
        ] = None,
        min_doubling_time: Annotated[
            Optional[
                Union[
                    Annotated[float, Field(strict=True, ge=0)],
                    Annotated[int, Field(strict=True, ge=0)],
                ]
            ],
            Field(description="Minimum doubling time in hours"),
        ] = None,
        max_doubling_time: Annotated[
            Optional[
                Union[
                    Annotated[float, Field(strict=True, ge=0)],
                    Annotated[int, Field(strict=True, ge=0)],
                ]
            ],
            Field(description="Maximum doubling time in hours"),
        ] = None,
        exclude_double_picked: Annotated[
            Optional[StrictBool],
            Field(description="Exclude double-picked mutants (isdoublepicked=True)"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SuccessResponseSchema]:
        """Search mutant growth data with filters

        Search for mutant growth data across genes with optional filters. Supports identifier-based search and discovery mode (filter-only queries).

        :param locus_tags: Comma-separated list of locus tags to search for
        :type locus_tags: str
        :param uniprot_ids: Comma-separated list of UniProt IDs to search for
        :type uniprot_ids: str
        :param media: Filter by growth media
        :type media: str
        :param experimental_condition: Filter by experimental condition
        :type experimental_condition: str
        :param min_doubling_time: Minimum doubling time in hours
        :type min_doubling_time: float
        :param max_doubling_time: Maximum doubling time in hours
        :type max_doubling_time: float
        :param exclude_double_picked: Exclude double-picked mutants (isdoublepicked=True)
        :type exclude_double_picked: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_experimental_mutant_growth_endpoints_search_mutant_growth_serialize(
            locus_tags=locus_tags,
            uniprot_ids=uniprot_ids,
            media=media,
            experimental_condition=experimental_condition,
            min_doubling_time=min_doubling_time,
            max_doubling_time=max_doubling_time,
            exclude_double_picked=exclude_double_picked,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_experimental_mutant_growth_endpoints_search_mutant_growth_without_preload_content(
        self,
        locus_tags: Annotated[
            Optional[StrictStr],
            Field(description="Comma-separated list of locus tags to search for"),
        ] = None,
        uniprot_ids: Annotated[
            Optional[StrictStr],
            Field(description="Comma-separated list of UniProt IDs to search for"),
        ] = None,
        media: Annotated[
            Optional[StrictStr], Field(description="Filter by growth media")
        ] = None,
        experimental_condition: Annotated[
            Optional[StrictStr], Field(description="Filter by experimental condition")
        ] = None,
        min_doubling_time: Annotated[
            Optional[
                Union[
                    Annotated[float, Field(strict=True, ge=0)],
                    Annotated[int, Field(strict=True, ge=0)],
                ]
            ],
            Field(description="Minimum doubling time in hours"),
        ] = None,
        max_doubling_time: Annotated[
            Optional[
                Union[
                    Annotated[float, Field(strict=True, ge=0)],
                    Annotated[int, Field(strict=True, ge=0)],
                ]
            ],
            Field(description="Maximum doubling time in hours"),
        ] = None,
        exclude_double_picked: Annotated[
            Optional[StrictBool],
            Field(description="Exclude double-picked mutants (isdoublepicked=True)"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Search mutant growth data with filters

        Search for mutant growth data across genes with optional filters. Supports identifier-based search and discovery mode (filter-only queries).

        :param locus_tags: Comma-separated list of locus tags to search for
        :type locus_tags: str
        :param uniprot_ids: Comma-separated list of UniProt IDs to search for
        :type uniprot_ids: str
        :param media: Filter by growth media
        :type media: str
        :param experimental_condition: Filter by experimental condition
        :type experimental_condition: str
        :param min_doubling_time: Minimum doubling time in hours
        :type min_doubling_time: float
        :param max_doubling_time: Maximum doubling time in hours
        :type max_doubling_time: float
        :param exclude_double_picked: Exclude double-picked mutants (isdoublepicked=True)
        :type exclude_double_picked: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_experimental_mutant_growth_endpoints_search_mutant_growth_serialize(
            locus_tags=locus_tags,
            uniprot_ids=uniprot_ids,
            media=media,
            experimental_condition=experimental_condition,
            min_doubling_time=min_doubling_time,
            max_doubling_time=max_doubling_time,
            exclude_double_picked=exclude_double_picked,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_experimental_mutant_growth_endpoints_search_mutant_growth_serialize(
        self,
        locus_tags,
        uniprot_ids,
        media,
        experimental_condition,
        min_doubling_time,
        max_doubling_time,
        exclude_double_picked,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if locus_tags is not None:
            _query_params.append(("locus_tags", locus_tags))

        if uniprot_ids is not None:
            _query_params.append(("uniprot_ids", uniprot_ids))

        if media is not None:
            _query_params.append(("media", media))

        if experimental_condition is not None:
            _query_params.append(("experimental_condition", experimental_condition))

        if min_doubling_time is not None:
            _query_params.append(("min_doubling_time", min_doubling_time))

        if max_doubling_time is not None:
            _query_params.append(("max_doubling_time", max_doubling_time))

        if exclude_double_picked is not None:
            _query_params.append(("exclude_double_picked", exclude_double_picked))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["RoleBasedJWTAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/mutant-growth/search",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



"""Genome CLI commands."""

from __future__ import annotations

from pathlib import Path
from typing import List, Optional

import typer  # type: ignore[import]

from ..output import print_full_table, print_json, print_tsv
from ..utils import (
    comma_join,
    ensure_client,
    handle_raw_response,
    merge_params,
    print_paginated_result,
)

genomes_app = typer.Typer(help="Genome endpoints")


@genomes_app.command("list")
def list_genomes_command(
    ctx: typer.Context,
    page: Optional[int] = typer.Option(None, "--page", "-p"),
    per_page: Optional[int] = typer.Option(None, "--per-page"),
    sort_field: Optional[str] = typer.Option(None, "--sort-field"),
    sort_order: Optional[str] = typer.Option(None, "--sort-order"),
    format: Optional[str] = typer.Option(None, "--format", "-f", help="json|tsv"),
) -> None:
    client = ensure_client(ctx)
    result = client.list_genomes(
        format=format or "json",
        page=page,
        per_page=per_page,
        sortField=sort_field,
        sortOrder=sort_order,
    )
    print_paginated_result(result, format, title="Genomes")


@genomes_app.command("search")
def search_genomes(
    ctx: typer.Context,
    query: Optional[str] = typer.Option(None, "--query", "-q", help="Search term"),
    species_acronym: Optional[str] = typer.Option(None, "--species", "-s"),
    page: int = typer.Option(1, "--page", "-p"),
    per_page: int = typer.Option(10, "--per-page"),
    sort_field: Optional[str] = typer.Option(None, "--sort-field"),
    sort_order: Optional[str] = typer.Option(None, "--sort-order"),
    format: Optional[str] = typer.Option(
        None, "--format", "-f", help="Output format: json|tsv (default: table)"
    ),
) -> None:
    client = ensure_client(ctx)
    api_format = format or "json"  # Default to JSON for API request
    result = client.search_genomes(
        format=api_format,
        query=query,
        page=page,
        per_page=per_page,
        sort_field=sort_field,
        sort_order=sort_order,
        species_acronym=species_acronym,
    )

    if format == "tsv":
        print_tsv(result.items)
    elif format == "json":
        print_json(result.raw)
    else:
        # No format specified - display as table
        print_full_table(result.items, title="Genomes")


@genomes_app.command("type-strains")
def genomes_type_strains(
    ctx: typer.Context,
    format: Optional[str] = typer.Option(None, "--format", "-f", help="json|tsv"),
) -> None:
    client = ensure_client(ctx)
    response = client.raw_request("GET", "/api/genomes/type-strains", format=format)
    handle_raw_response(response, format, title="Type Strains")


@genomes_app.command("autocomplete")
def genomes_autocomplete(
    ctx: typer.Context,
    query: str = typer.Option(..., "--query", "-q", help="Search term"),
    limit: Optional[int] = typer.Option(5, "--limit"),
    species_acronym: Optional[str] = typer.Option(None, "--species", "-s"),
    format: Optional[str] = typer.Option(None, "--format", "-f", help="json|tsv"),
) -> None:
    client = ensure_client(ctx)
    params = merge_params(
        {
            "query": query,
            "limit": limit,
            "species_acronym": species_acronym,
        }
    )
    response = client.raw_request(
        "GET", "/api/genomes/autocomplete", params=params, format=format
    )
    handle_raw_response(response, format, title="Genome Autocomplete")


@genomes_app.command("download")
def genomes_download_tsv(
    ctx: typer.Context,
    output: Optional[Path] = typer.Option(
        None, "--output", "-o", help="Destination file (defaults to stdout)"
    ),
) -> None:
    client = ensure_client(ctx)
    response = client.raw_request("GET", "/api/genomes/download/tsv", format="tsv")
    content = response.text
    if output:
        output.write_text(content)
        typer.echo(f"Wrote {output}")
    else:
        typer.echo(content)


@genomes_app.command("by-isolates")
def genomes_by_isolates(
    ctx: typer.Context,
    isolate: List[str] = typer.Option(..., "--isolate", "-i", help="Isolate name(s)"),
    format: Optional[str] = typer.Option(None, "--format", "-f", help="json|tsv"),
) -> None:
    client = ensure_client(ctx)
    params = {"isolates": comma_join(isolate)}
    response = client.raw_request(
        "GET", "/api/genomes/by-isolate-names", params=params, format=format
    )
    handle_raw_response(response, format, title="Genomes by isolate")


@genomes_app.command("genes")
def genomes_genes(
    ctx: typer.Context,
    isolate_name: str = typer.Argument(..., help="Genome isolate name"),
    filter: Optional[str] = typer.Option(None, "--filter", help="Filter expression"),
    filter_operators: Optional[str] = typer.Option(None, "--filter-operators"),
    page: Optional[int] = typer.Option(None, "--page", "-p"),
    per_page: Optional[int] = typer.Option(None, "--per-page"),
    sort_field: Optional[str] = typer.Option(None, "--sort-field"),
    sort_order: Optional[str] = typer.Option(None, "--sort-order"),
    format: Optional[str] = typer.Option(None, "--format", "-f"),
) -> None:
    client = ensure_client(ctx)
    params = merge_params(
        {
            "filter": filter,
            "filter_operators": filter_operators,
            "page": page,
            "per_page": per_page,
            "sort_field": sort_field,
            "sort_order": sort_order,
        }
    )
    response = client.raw_request(
        "GET",
        f"/api/genomes/{isolate_name}/genes",
        params=params,
        format=format,
    )
    handle_raw_response(response, format, title=f"Genes for {isolate_name}")


@genomes_app.command("essentiality")
def genomes_essentiality(
    ctx: typer.Context,
    isolate_name: str = typer.Argument(..., help="Genome isolate name"),
    ref_name: str = typer.Argument(..., help="Reference/contig name"),
    format: Optional[str] = typer.Option(None, "--format", "-f"),
) -> None:
    client = ensure_client(ctx)
    response = client.raw_request(
        "GET",
        f"/api/genomes/{isolate_name}/essentiality/{ref_name}",
        format=format,
    )
    handle_raw_response(
        response, format, title=f"Essentiality {isolate_name}:{ref_name}"
    )


@genomes_app.command("drug-mic")
def genomes_drug_mic(
    ctx: typer.Context,
    isolate_name: str = typer.Argument(...),
    page: Optional[int] = typer.Option(None, "--page", "-p"),
    per_page: Optional[int] = typer.Option(None, "--per-page"),
    format: Optional[str] = typer.Option(None, "--format", "-f"),
) -> None:
    client = ensure_client(ctx)
    params = merge_params({"page": page, "per_page": per_page})
    response = client.raw_request(
        "GET",
        f"/api/genomes/{isolate_name}/drug-mic",
        params=params,
        format=format,
    )
    handle_raw_response(response, format, title=f"Drug MIC ({isolate_name})")


@genomes_app.command("drug-metabolism")
def genomes_drug_metabolism(
    ctx: typer.Context,
    isolate_name: str = typer.Argument(...),
    page: Optional[int] = typer.Option(None, "--page", "-p"),
    per_page: Optional[int] = typer.Option(None, "--per-page"),
    format: Optional[str] = typer.Option(None, "--format", "-f"),
) -> None:
    client = ensure_client(ctx)
    params = merge_params({"page": page, "per_page": per_page})
    response = client.raw_request(
        "GET",
        f"/api/genomes/{isolate_name}/drug-metabolism",
        params=params,
        format=format,
    )
    handle_raw_response(response, format, title=f"Drug metabolism ({isolate_name})")


@genomes_app.command("drug-data")
def genomes_drug_data(
    ctx: typer.Context,
    isolate_name: str = typer.Argument(...),
    format: Optional[str] = typer.Option(None, "--format", "-f"),
) -> None:
    client = ensure_client(ctx)
    response = client.raw_request(
        "GET",
        f"/api/genomes/{isolate_name}/drug-data",
        format=format,
    )
    handle_raw_response(response, format, title=f"Drug data ({isolate_name})")



from __future__ import annotations

from click.testing import CliRunner
from typer.main import get_command

from mett_client.cli.main import app as cli_app
from .test_cli import _patch_dummy_client


runner = CliRunner()
cli_cmd = get_command(cli_app)


def test_drugs_mic_by_drug(monkeypatch) -> None:
    """Friendly CLI: mett drugs mic-by-drug azithromycin --format json"""
    _patch_dummy_client(monkeypatch)
    result = runner.invoke(
        cli_cmd, ["drugs", "mic-by-drug", "azithromycin", "--format", "json"]
    )
    assert result.exit_code == 0


def test_drugs_metabolism_search_query(monkeypatch) -> None:
    """Friendly CLI: mett drugs metabolism-search --query amoxapine --format json"""
    _patch_dummy_client(monkeypatch)
    result = runner.invoke(
        cli_cmd,
        ["drugs", "metabolism-search", "--query", "amoxapine", "--format", "json"],
    )
    assert result.exit_code == 0


def test_ppi_scores_available(monkeypatch) -> None:
    """Friendly CLI: mett ppi scores --format json"""
    _patch_dummy_client(monkeypatch)
    result = runner.invoke(cli_cmd, ["ppi", "scores", "--format", "json"])
    assert result.exit_code == 0


def test_ppi_network_properties_ds_score(monkeypatch) -> None:
    """Friendly CLI: mett ppi network-properties --score-type ds_score --score-threshold 0.8 --species PV --format json"""
    _patch_dummy_client(monkeypatch)
    result = runner.invoke(
        cli_cmd,
        [
            "ppi",
            "network-properties",
            "--score-type",
            "ds_score",
            "--score-threshold",
            "0.8",
            "--species",
            "PV",
            "--format",
            "json",
        ],
    )
    assert result.exit_code == 0


def test_orthologs_pair(monkeypatch) -> None:
    """Friendly CLI: mett orthologs pair --gene-a BU_ATCC8492_00001 --gene-b PV_ATCC8482_00001 --format json"""
    _patch_dummy_client(monkeypatch)
    result = runner.invoke(
        cli_cmd,
        [
            "orthologs",
            "pair",
            "--gene-a",
            "BU_ATCC8492_00001",
            "--gene-b",
            "PV_ATCC8482_00001",
            "--format",
            "json",
        ],
    )
    assert result.exit_code == 0


def test_operons_search_min_genes(monkeypatch) -> None:
    """Friendly CLI: mett operons search --min-genes 2 --format json

    Note: we intentionally omit the boolean flags here (--has-tss/--has-terminator)
    to avoid depending on Click's boolean parsing details. The goal of this test
    is to exercise the command wiring and parameter plumbing, not every flag combo.
    """
    _patch_dummy_client(monkeypatch)
    result = runner.invoke(
        cli_cmd,
        [
            "operons",
            "search",
            "--min-genes",
            "2",
            "--format",
            "json",
        ],
    )
    assert result.exit_code == 0


def test_operons_statistics_species(monkeypatch) -> None:
    """Friendly CLI: mett operons statistics --species BU --format json"""
    _patch_dummy_client(monkeypatch)
    result = runner.invoke(
        cli_cmd, ["operons", "statistics", "--species", "BU", "--format", "json"]
    )
    assert result.exit_code == 0


def test_fitness_search_locus_tag(monkeypatch) -> None:
    """Friendly CLI: mett fitness search --locus-tag BU_ATCC8492_00002 --format json"""
    _patch_dummy_client(monkeypatch)
    result = runner.invoke(
        cli_cmd,
        ["fitness", "search", "--locus-tag", "BU_ATCC8492_00002", "--format", "json"],
    )
    assert result.exit_code == 0


def test_fitness_correlations_search(monkeypatch) -> None:
    """Friendly CLI: mett fitness-correlations search --query \"Vitamin B12\" --format json"""
    _patch_dummy_client(monkeypatch)
    result = runner.invoke(
        cli_cmd,
        [
            "fitness-correlations",
            "search",
            "--query",
            "Vitamin B12",
            "--format",
            "json",
        ],
    )
    assert result.exit_code == 0


def test_fitness_correlations_pair(monkeypatch) -> None:
    """Friendly CLI: mett fitness-correlations correlation --locus-tag-a BU_ATCC8492_02530 --locus-tag-b BU_ATCC8492_02762 --format json"""
    _patch_dummy_client(monkeypatch)
    result = runner.invoke(
        cli_cmd,
        [
            "fitness-correlations",
            "pair",
            "--gene-a",
            "BU_ATCC8492_02530",
            "--gene-b",
            "BU_ATCC8492_02762",
            "--format",
            "json",
        ],
    )
    assert result.exit_code == 0


def test_drugs_mic_filters(monkeypatch) -> None:
    """Friendly CLI: mett drugs mic --drug-name amoxicillin --species BU --min-mic-value 35.0 --max-mic-value 45.0 --format json"""
    _patch_dummy_client(monkeypatch)
    args = [
        "drugs",
        "mic",
        "--drug-name",
        "amoxicillin",
        "--species",
        "BU",
        "--min-mic-value",
        "35.0",
        "--max-mic-value",
        "45.0",
        "--format",
        "json",
    ]
    result = runner.invoke(cli_cmd, args)
    assert result.exit_code == 0


def test_ppi_interactions(monkeypatch) -> None:
    """Friendly CLI: mett ppi interactions --locus-tag BU_ATCC8492_01788 --species BU --per-page 3 --format json"""
    _patch_dummy_client(monkeypatch)
    args = [
        "ppi",
        "interactions",
        "--locus-tag",
        "BU_ATCC8492_01788",
        "--species",
        "BU",
        "--per-page",
        "3",
        "--format",
        "json",
    ]
    result = runner.invoke(cli_cmd, args)
    assert result.exit_code == 0


def test_ttp_hits(monkeypatch) -> None:
    """Friendly CLI: mett ttp hits --max-fdr 0.05 --min-ttp-score 1.0 --format json"""
    _patch_dummy_client(monkeypatch)
    args = [
        "ttp",
        "hits",
        "--max-fdr",
        "0.05",
        "--min-ttp-score",
        "1.0",
        "--format",
        "json",
    ]
    result = runner.invoke(cli_cmd, args)
    assert result.exit_code == 0


def test_pyhmmer_databases(monkeypatch) -> None:
    """Friendly CLI: mett pyhmmer databases --format json"""
    _patch_dummy_client(monkeypatch)
    result = runner.invoke(cli_cmd, ["pyhmmer", "databases", "--format", "json"])
    assert result.exit_code == 0



"""CLI output helpers using Rich."""

from __future__ import annotations

import csv
import json
import sys
from typing import Any, Dict, Iterable, List, Mapping, Sequence, Tuple

from rich.console import Console  # type: ignore[import]
from rich.table import Table  # type: ignore[import]

console = Console()

Column = Tuple[str, callable]


def print_table(
    rows: Iterable[object], columns: Sequence[Column], *, title: str
) -> None:
    rows = list(rows)
    if not rows:
        console.print("No results found", style="yellow")
        return
    table = Table(title=title)
    for header, _ in columns:
        table.add_column(header)

    for row in rows:
        table.add_row(*[str(getter(row) or "") for _, getter in columns])
    console.print(table)


def print_full_table(rows: Iterable[object], *, title: str) -> None:
    normalized = [_normalize_row(row) for row in rows]
    if not normalized:
        console.print("No results found", style="yellow")
        return

    headers: List[str] = sorted({key for row in normalized for key in row.keys()})
    table = Table(title=title)
    for header in headers:
        table.add_column(header)

    for row in normalized:
        table.add_row(*[_stringify(row.get(header)) for header in headers])
    console.print(table)


def print_json(data: object) -> None:
    console.print_json(data=json.loads(json.dumps(data, default=str)))


def print_tsv(rows: Iterable[object]) -> None:
    """Print rows as raw TSV (tab-separated values) for piping to files."""
    normalized = [_normalize_row(row) for row in rows]
    if not normalized:
        return

    headers: List[str] = sorted({key for row in normalized for key in row.keys()})

    # Use csv.writer with tab delimiter for proper TSV formatting
    writer = csv.writer(sys.stdout, delimiter="\t", lineterminator="\n")
    writer.writerow(headers)

    for row in normalized:
        values = [_tsv_value(row.get(header)) for header in headers]
        writer.writerow(values)


def _normalize_row(row: object) -> Dict[str, Any]:
    if isinstance(row, Mapping):
        return dict(row)
    if hasattr(row, "model_dump"):
        return row.model_dump()
    if hasattr(row, "__dict__"):
        return {k: v for k, v in vars(row).items() if not k.startswith("_")}
    return {"value": row}


def _stringify(value: Any) -> str:
    if value is None:
        return ""
    if isinstance(value, (dict, list)):
        try:
            return json.dumps(value, ensure_ascii=False)
        except Exception:  # pragma: no cover
            return str(value)
    return str(value)


def _tsv_value(value: Any) -> str:
    """Convert value to TSV-safe string."""
    if value is None:
        return ""
    if isinstance(value, (dict, list)):
        try:
            return json.dumps(value, ensure_ascii=False)
        except Exception:  # pragma: no cover
            return str(value)
    return str(value)
